pyDARTlab — pydartlab 0.0.1 documentation

# pyDARTlab

pyDARTlab is a Python package for learning Data Assimilation based on DARTLAB from the Data Assimilation Research Testbed (DART).

Note

pyDARTlab is under initial development, so please use caution. The MATLAB versino of DARTLAB is available through DART.

# Contributing

Contributions are welcome! If you have a feature request, bug report, or a suggestion, please open an issue on our GitHub repository.

# License

pyDARTLab is released under the Apache License 2.0. For more details, see the LICENSE file in the root directory of this source tree or visit Apache License 2.0.